Español para inmigrantes y refugiados | Blog de recursos para la enseñanza de español a inmigrantes y refugiados
Description: Blog de recursos para la enseñanza de español a inmigrantes y refugiados

# Español para inmigrantes y refugiados

Blog de recursos para la enseñanza de español a inmigrantes y refugiados

## Actividades para la clase de español 5

Publicado el diciembre 2, 2015| Deja un comentario

### Share this:

- Correo electrónico
- Facebook
- Twitter
- Pinterest

### Me gusta:

Me gusta Cargando...

Deja un comentario

Publicado en ACTIVIDADES / EJERCICIOS, ACTIVIDADES LÚDICAS, DINÁMICAS, LÉXICO

Etiquetado actividades, ELE, Juegos

## Halloween

Publicado el octubre 31, 2015| 2 comentarios

- ### LOS_MONSTRUOS

### Share this:

- Correo electrónico
- Facebook
- Twitter
- Pinterest

### Me gusta:

Me gusta Cargando...

2 comentarios

Publicado en ACTIVIDADES / EJERCICIOS, CELEBRACIONES

Etiquetado preposiciones

## Las emociones

Publicado el julio 9, 2015| 4 comentarios

- ### EL BAZAR DE LAS EMOCIONES

- ### DOMINÓ DE LOS SENTIMIENTOS

### Share this:

- Correo electrónico
- Facebook
- Twitter
- Pinterest

### Me gusta:

Me gusta Cargando...

4 comentarios

Publicado en Estados de ánimo, EStados de ánimo, imágenes, INMIGRANTES /REFUGIADOS

## ¿Jugamos? Juegos y actividades lúdicas (4)

Publicado el junio 10, 2015| Deja un comentario

Más juegos y actividades lúdicas aquí:

- https://espanolparainmigrantes.wordpress.com/2015/03/01/jugamos/
- https://espanolparainmigrantes.wordpress.com/2014/12/27/ideas-actividades-dinamicas-para-la-clase-de-ele/
- https://espanolparainmigrantes.wordpress.com/2013/11/28/juegos-y-actividadesde-ludicas-3/
- https://espanolparainmigrantes.wordpress.com/2010/12/19/juegos-para-practicar-espanol-2/
- https://espanolparainmigrantes.wordpress.com/2009/11/15/juegos/

### Share this:

- Correo electrónico
- Facebook
- Twitter
- Pinterest

### Me gusta:

Me gusta Cargando...

Deja un comentario

Publicado en ACTIVIDADES LÚDICAS, DINÁMICAS, ELE, Gamificación, INMIGRANTES /REFUGIADOS, JUEGOS

Etiquetado Dinámicas Gamificación, ELE, Juegos

## LA POESÍA EN EL AULA DE ELE

Publicado el junio 3, 2015| 1 comentario

- LA POESÍA EN LA CLASE DE ELE

- ### PRESENTE DE INDICATIVO.ESPACIO PARA UNA POÉTICA

- ### DIDÁCTICA DE LA POESÍA: ESTUDIO Y PROPUESTAS METODOLÓGICAS PARA LA EXPLOTACIÓN DE TEXTOS POÉTICOS EN EL AULA DE ELE

### Poemas Diamante:

#### Son poemas de 7 versos asonantes en forma de diamante.

#### El primer verso consiste de un sustantivo; el segundo de dos adjetivos que describan al sustantivo; el tercero, de tres verbos; el cuarto, de cuatro sustantivos (los dos últimos deben tener un significado opuesto a los dos primeros); el quinto, de tres verbos que reflejen el cambio en el sujeto del poema; el sexto, de dos adjetivos que continúen la idea del cambio; y el séptimo, de un sustantivo que sea opuesto al primer sustantivo.(*)

- 1a línea: un nombre de persona o cosa.
- 2a línea: dos adjetivos que describan al nombre de la primera línea.
- 3a línea: tres verbos relacionados con la primera línea.
- 4a línea: cuatro nombres: dos relacionados con la primera línea y dos con la séptima.
- 5a línea: tres verbos relacionados con la séptima línea.
- 6a línea: dos adjetivos que describan la séptima línea.
- 7a línea: un nombre contrario o antónimo al de la primera línea.

#### Plantas

#### verdes, variadas,

#### crecen, trepan, perfuman.

#### Enredaderas, arbustos, esmeraldas, zafiros

#### brillan, relucen, adornan

#### verdes, azules,

#### piedras.

####

#### Tigres

#### salvajes, felinos,

#### corren, muerden, cazan,

#### grandes, veloces, lentos, pequeños,

#### caminan, nadan, comen,

#### caparazón, verdes,

#### tortugas

#### El acróstico más característico de la lengua española está constituido por los versos que conforman el Prólogo de La Celestina deFernando de Rojas, (1499), en cuyas octavas se puede leer la siguiente frase:

#### El bachiller

      El silencio escuda y suele encubrir
      Las faltas de ingenio e las torpes lenguas;
      Blasón que es contrario publica sus menguas
      Al que mucho habla sin mucho sentir.
      Como la hormiga que deja de ir
      Holgando por tierra con la provisión,
      Iactóse con alas de su perdición:
      LLeváronla en alto, no sabe dónde ir.

      El aire gozando, ajeno y extraño,
      Rapiña es ya hecha de aves que vuelan;

### Share this:

- Correo electrónico
- Facebook
- Twitter
- Pinterest

### Me gusta:

Me gusta Cargando...

1 comentario

Publicado en INMIGRANTES /REFUGIADOS, POEMAS, POESÍA

Etiquetado acróstico, ELE, poema diamante, poemas, POESÍA

## El léxico en el aula de ELE

Publicado el mayo 18, 2015| Deja un comentario

#### Propuesta de una herramienta lingüística.” El Español en el aula”

#####

### Share this:

- Correo electrónico
- Facebook
- Twitter
- Pinterest

### Me gusta:

Me gusta Cargando...

Deja un comentario

Publicado en INMIGRANTES /REFUGIADOS

Etiquetado ELE, léxico

Imagen

## Taller extraordinario de enseñanza de ELE. Entre el profesor analógico y el digital

- ### Monográfico_FlippedClassroom_Fundación Telefónica

- #### Herramientas para grabar tus propias videolecciones

### Share this:

- Correo electrónico
- Facebook
- Twitter
- Pinterest

### Me gusta:

Me gusta Cargando...

Deja un comentario

Publicado el mayo 13, 2015 in Blended learning, CURSOS, flipped learning, Gamificación, la clase invertida, TALLERES, Talleres de formación ELE inmigrantes, TICS

## EXPRESIONES IDIOMÁTICAS

Publicado el mayo 6, 2015| 1 comentario

### Share this:

- Correo electrónico
- Facebook
- Twitter
- Pinterest

### Me gusta:

Me gusta Cargando...

1 comentario

Publicado en ACTIVIDADES / EJERCICIOS, EXPRESIONES IDIOMÁTICAS, INMIGRANTES /REFUGIADOS, LÉXICO

Etiquetado expresiones idiomáticas, léxico

## ¿JUGAMOS?

Publicado el marzo 1, 2015| 8 comentarios

¿Jugamos? Juegos tradicionales del mundo hispánico

Juego de la editorial ACENTO ESPAÑOL

### Share this:

- Correo electrónico
- Facebook
- Twitter
- Pinterest

### Me gusta:

Me gusta Cargando...

8 comentarios

Publicado en ACTIVIDADES LÚDICAS, DINÁMICAS, INMIGRANTES /REFUGIADOS, JUEGOS

## #TE VI. ¿Alguna vez has querido decirle algo a alguien en el metro pero no te has atrevido?

Publicado el febrero 1, 2015| 2 comentarios

¿Qué es el #TeVi? es un hastag que nos sirve para aglutinar frases, de 140 caracteres, que expresen esa situación, que todos hemos vivido, de quedarnos mirando a alguien en el Metro, enamorarnos por un microsegundos y no atrevernos a decirle nada. Pues bien, es nuestra oportunidad, todos los mensajes que recibamos a través de twitter, facebook, instagram o incluso a través del mail, los transcribiremos en una pared de la estación de Legazpi. Puedes inmortalizar un momento y hacerlo único y a la vez compartirlo con los demás, como un pequeño homenaje a una situación ‘medio secreta’, o una fantasía incluso, que te hizo feliz por unos minutos. Puedes decidir que tu mensaje sea anónimo o que aparezca tu nombre de internet: @lagaleriade

¡A partir del 26 estaremos llenando de mensajes la estación de Legazpi, anímate a participar y mándanos una frase!

Metro anima a los viajeros a “tuitear” lo que quisieron decir a alguien que vieron en el metro y nunca se atrevieron

Con la etiqueta #TeVi, podrán dejar un mensaje a la persona con la que les hubiera gustado hablar en el suburbano. Nueva iniciativa artística promovida por La Galería de la Magdalena dentro del proyecto “Línea Zero, arte urbano en Metro de Madrid”. La estación de Legazpi albergará un muro artístico con los mensajes más curiosos y originales. La Comunidad de Madrid sigue apostando por Metro como espacio de arte urbano y convivencia

Metro de Madrid anima a los viajeros a que participen en una iniciativa de la Galería de Magdalena por la que, a través del hastag #TeVi, pueden publicar mensajes en Twitter dirigidos a todas aquellas personas, o aquella persona especial, con la que un día se cruzaron en el Metro y no se atrevieron a decirle nada. Con esta iniciativa, La Comunidad de Madrid sigue apostando por el arte urbano como expresión artística cercana al usuario de Metro ya que es el viajero el auténtico protagonista de esta nueva y vanguardista propuesta.

Los mensajes más curiosos y originales serán seleccionados para formar parte de un muro artístico que se llevará a cabo en la estación de Legazpi. Se trata de una nueva intervención enmarcada en el proyecto “Línea Zero, arte urbano en metro de Madrid”, en la que la Comunidad de Madrid, junto a Madrid Street Art Project, buscan acercar el arte urbano a todos los madrileños a través de la red de Metro. Esta innovadora acción artística, pionera en España, comenzó su recorrido en la nueva estación Paco de Lucía. Allí dos artistas urbanos de reconocido prestigio, Okuda y Rosh333 están finalizando la decoración de un mural de 300 metros cuadrados que rinde homenaje al guitarrista universal, Paco de Lucía.

La segunda acción de Línea Zero fue la decoración de la estación de Moncloa por parte del colectivo madrileño “La banda del Rotu” formado por los artistas Mufasa, RBN, Curruncho, Sabek y Astro Naut que juntos han pintado con rotulador y energía inagotable los pasillos y andenes de la línea 3 en esta estación.

La tercera acción de Línea Zero, capitaneada esta vez por el grupo artístico La Galería de Magdalena ha consistido en una serie de jornadas en las que se han entregado regalos urbanos, en concreto #RegaloSuburbanos, en diversas estaciones de la línea 3 e incluso dentro de los trenes
Mensajes para todos en la estación de Legazpi La Galería de Magdalena será la encargada de hacer una selección de los mensajes que publiquen los viajeros de Metro bajo la etiqueta #teVI para dejarlos después plasmados de forma temporal en una pared de la estación de Legazpi. Las responsables de la acción han lanzado ya algunos mensajes como ejemplo del tipo de la idea que pretenden plasmar con esta iniciativa: #TeVi al otro lado del andén, pasó tu tren y desapareciste. #TeVi y ya no dejo de pensar en ti. #TeVi esperando en el andén de la línea 6 y no me atrevía decirte lo guapa que eres. Los dos leíamos libros de poemas, #TeVi pero nunca te dije nada.

Hasta el próximo día 22, los viajeros de Metro podrán participar enviando mensajes que hacen de esta acción un propuesta original y diferente de las organizadas hasta ahora, y en la que además, habrán sido ellos mismos los autores de lo que luego se expondrá.

El arte urbano es una de las manifestaciones artísticas más rupturistas, globales y con mayor auge del arte contemporáneo actual. Por otro lado, Metro es sin duda uno de los emblemas de la ciudad, del que miles de personas hacen uso a diario y en el que emplean parte de su tiempo cotidiano para trasladarse de un lugar a otro. Línea Zero persigue aunar arte y transporte público, convirtiendo y aprovechando los espacios del suburbano en una galería a la que trasladar muestras del arte que se lleva a cabo en la calle, consiguiendo que el viajero pueda disfrutar de éste de una manera natural y accesible

### Share this:

- Correo electrónico
- Facebook
- Twitter
- Pinterest

### Me gusta:

Me gusta Cargando...

2 comentarios

Publicado en INMIGRANTES /REFUGIADOS

- ### Requisitos para conseguir la nacionalidad española

- ### Categorías

  Categorías
- Buscar:

- ### Estadísticas del blog

  - 4,169,016 hits

- ### Sigue el blog por Email

  Introduce tu dirección de correo electrónico para seguir este Blog y recibir las notificaciones de las nuevas publicaciones en tu buzón de correo electrónico.

  Únete a otros 1.868 seguidores

- Follow Español para inmigrantes y refugiados on WordPress.com

- ### Comunidad

- ### Español para inmigrantes y refugiados

  - Actividades para la clase de español 5 diciembre 2, 2015
    Archivado en: ACTIVIDADES / EJERCICIOS, ACTIVIDADES LÚDICAS, DINÁMICAS, LÉXICO Tagged: actividades, ELE, Juegos
    Nines Picado

- No es posible cargar la información del blog en este momento.

- ###

  ACTIVIDADES / EJERCICIOS ACTIVIDADES LÚDICAS ALFABETIZACIÓN CANCIONES ELE CELEBRACIONES CURSOS DINÁMICAS ELE El imperativo español para inmigrantes Estados de ánimo FIESTAS Gastronomía/Vocabulario culinario imágenes inmigracion INMIGRANTES /REFUGIADOS interculturalidad JUEGOS LECTO-ESCRITURA MANUALES / UNIDADES DIDÁCTICAS SER y ESTAR TALLERES Talleres de formación ELE inmigrantes TIEMPOS VERBALES TRADICIONES VERBOS Vocabulario/léxico ÁFRICA

- ### Lectorados MAEC-AECID 2015-2016

- ### Free rice en español

  El juego de vocabulario que te permite enriquecer tu vocabulario y a la vez alimentar con arroz a las personas que padecen hambre.

- ### DEJA AQUÍ TUS SUGERENCIAS, DIRECCIONES, COMENTARIOS,VIDEOS..

- ### Comentarios recientes

  | jJosé Castillo Ordóñ… on SOLIDARIDAD / VOLUNTARIADO
  | jJosé Castillo Ordóñ… on SOLIDARIDAD / VOLUNTARIADO
  | Monica on Las emociones
  | Miguel Ortegaytán on CURSOS DE ESPAÑOL ON-LINE
  | Nines Picado on CLASES DE ESPAÑOL PARA INMIGRA…
  | Mar on CLASES DE ESPAÑOL PARA INMIGRA…
  | Ali on GUÍA PARA PERSONAS SIN PA…
  | Ali on GUÍA PARA PERSONAS SIN PA…
  | Andres david on GUÍA PARA PERSONAS SIN PA…
  | lyu on GUÍA PARA PERSONAS SIN PA…
  | pato on GUÍA PARA PERSONAS SIN PA…
  | pato on GUÍA PARA PERSONAS SIN PA…
  | inespoenes on BLOGS
  | mina on GUÍA PARA PERSONAS SIN PA…
  | Laura on GUÍA PARA PERSONAS SIN PA…

- ### ESCUCHA EN ESPAÑOL

- SOS RACISMO

- ### Estancia irregular. ¿Multa o expulsión?

- ### GUÍA PARA PERSONAS SIN PAPELES

- ### Unidad Didáctica Derechos Humanos

- ### Los estudiantes nos cuentan cosas.Tú también puedes participaR.

- ### Entradas recientes

  - Actividades para la clase de español 5
  - Halloween
  - Las emociones
  - ¿Jugamos? Juegos y actividades lúdicas (4)
  - LA POESÍA EN EL AULA DE ELE

- ### Mejor calificado

- ### Español para inmigrantes y refugiados

  - RT @wagjuer: La clase en juego con LearningApps - un webinario gratis globinars.blogspot.de/2016/01/la-cla… https://t.co/okTq0wCzx9 1 week ago
  - GUÍA DE APRENDIZAJE INVERTIDO FLIPPED CLASSROOM orientacionandujar.es/2016/01/09/gui… vía @maribelandu 2 weeks ago
  - RT @AccionPoeticaw: Humanidad ¿Dónde te fuiste? 3 weeks ago
  - https://t.co/rYafxUNYz6 4 weeks ago
  - RT @CEARefugio: Nuestro deseo para el año que viene: https://t.co/AzdcQL6Jt9 4 weeks ago
  Follow @Espanolinmigran

- ### CLASES DE ESPAÑOL EN MADRID

- ### SOY MIEMBRO DE ASILIM

- ### SOY MIEMBRO DE TODOELE

- ### Upcoming Events

  No existen eventos próximos

- ### ENTRE TODOS

- ### CAMPAÑA

- ### Canal de Español para inmigrantes

- ### Directorio de España

- ### MATERIALES PARA LA ENSEÑANZA DE ESPAÑOL

- ### MY SLIDESHARE

- ### Método de lecto-escritura

- ### ¿QUIERES SABER TU NIVEL DE ESPAÑOL?

- ### PRUEBA DE NIVEL. En el enlace siguiente puedes realizar gratuitamente un test para evaluar tu nivel de Español siguiendo el Marco Europeo de Referencia para las Lenguas. ¿Qué puntuación has obtenido?

- ### Practica español escuchando la radio

- ### CURSOS DE ESPAÑOL EN LÍNEA

- ### Memorizar palabras de una manera fácil y eficaz, a través de imágenes, sonidos y juegos

- ### LOS SONIDOS DEL ESPAÑOL

- ### PASAR TEXTO A mp3

- ### Actividades del Aula Virtual de Español.

- ### MATERIALES DIGITALES PARA EL APRENDIZAJE ACTIVO DE LA ORTOGRAFÍA

- ### Mis primeras lecciones de español

- ### PRONOMBRES PERSONALES

- ### VERBOS EN -AR

- ### VERBOS EN -ER

- ### VERBOS EN -IR

- ### VERBO TENER

- ### Verbos, sólo verbos

- ### Top Clicks

  - espanolparainmigrantes.fi…
  - gloriadomene.googlepages.…
  - espanolparainmigrantes.fi…
  - espanolparainmigrantes.fi…
  - espanolparainmigrantes.fi…
  - espanolparainmigrantes.fi…
  - meduco.org/index.php?Mate…
  - aulapt.wordpress.com/a-l
  - espanolparainmigrantes.fi…
  - edu.xunta.es/web/nahono

- ### FICHAS DE ESPAÑOL

  FICHAS DE ESPAÑOL PARA EXTRANJEROS

- ### CALIGRAFÍA

  GENERADOR DE ACTIVIDADES DE CALIGRAFÍA

  GENERADOR DE FICHAS

- ### DICCIONARIO VISUAL ESPAÑOL-RUMANO

  DICCIONARIO ESPAÑOL-RUMANO

- ### DICCIONARIO Castellano-Árabe

- ### LECCIÓN DE GRAMÁTICA

  Yo estoy, tú estás y ella
  Está y él también;
  Y todos los que estaban estuvieron
  Y están muy bien.
  Estamos, estaremos
  Nosotros, ella y él
  Estarán lado a lado y yo, que estuve,
  Estaré.Y si acaso estuvieraAlguien que no haya estado aquella vez,¡bienvenido!, que estar es lo importantey que todos estén.
  David Fernández (Cuba)

- ### NACIONALIDADES

- ### PLAYING FOR CHANGE

  Playing For Change es un movimiento multimedia creado para inspirar, conectar y promover la paz en el mundo. La idea del proyecto surge de la convicción de que la música desarma las fronteras y nos ayuda a superar nuestras diferencias. No importa cuales sean nuestros orígenes geográficos, políticos, económicos, espirituales o ideológicos, la música tiene el poder universal de trascenderlos y de unirnos como habitantes de un mismo planeta. ONE LOVE

- ### SI TÚ FUERAS YO

  “Si tú fueras yo”, una animación con la que el internauta podrá ponerse en la piel de tres personas inmigrantes y vivir diversas etapas de su paso por España. Ibou, Teresa y Mariam prestan rostro e historia a los miles de personas inmigrantes que, por diversas razones, se vieron obligados a abandonar su lugar de origen para emprender la búsqueda de una vida mejor. SI TÚ FUERAS YO

- enero 2016
  M | T | W | T | F | S | S
  --- | --- | --- | --- | --- | --- | ---
  « Dec |  |
  | 1 | 2 | 3
  4 | 5 | 6 | 7 | 8 | 9 | 10
  11 | 12 | 13 | 14 | 15 | 16 | 17
  18 | 19 | 20 | 21 | 22 | 23 | 24
  25 | 26 | 27 | 28 | 29 | 30 | 31

- ### Archivos

  Archivos

- ### Blogroll

  - WordPress.com
  - WordPress.org

- ### BLOGS

  - BLOG DE ZAILDA
  - ELE y … ¡OLÉ!
  - Mundoele
  - RECURSOS PARA EL APRENDIZAJE DEL LENGUAJE ORAL, LECTURA Y ESCRITURA

- ### CURSOS DE ESPAÑOL

  - APRENDIZAJE DE ESPAÑOL

- ### Enseñanza Inmigrantes

  - Español Activo.Español para inmigrantes

- ### FOTOS

  - El PAÍS DOGÓN (MALI)
  - FOTOS DE MALI Y BURKINA FASO

- ### NOTICIAS /INFORMACIÓN

  - AFRICANEANDO
  - AFROLNEWS

- ### ONG/Asociaciones

  - ACCEM
  - AFROAID
  - ASILIM
  - ASTI.(Asociación de Solidaridad con los Trabajadores Inmigrantes)
  - CASA DE SENEGAL en Madrid
  - CEAR

- ### PARA PROFES

  - MARCOELE
  - TODOELE

- ### Categorías

  - ACTIVIDADES / EJERCICIOS (31)
  - ACTIVIDADES LÚDICAS (15)
  - ALFABETIZACIÓN (14)
  - ÁFRICA (3)
  - bambara (1)
  - Blended learning (1)
  - BUSCO TRABAJO (1)
  - CANCIONES ELE (2)
  - CANCIONES en español (1)
  - CANCIONES sobre INMIGRACIÓN (1)
  - CELEBRACIONES (5)
  - CINE sobre inmigración (1)
  - CURSOS (3)
  - Cursos de español online (1)
  - DESCRIPCIÓN (1)
  - DINÁMICAS (12)
  - diplomas (1)
  - El imperativo (2)
  - EL IMPERFECTO (1)
  - EL PRESENTE DE INDICATIVO (1)
  - EL PRETÉRITO INDEFINIDO (1)
  - EL PRETÉRITO PERFECTO (1)
  - ELE (14)
  - español para inmigrantes (13)
  - Estados de ánimo (2)
    - EStados de ánimo (1)
  - EXPRESIONES IDIOMÁTICAS (1)
  - FIESTAS (3)
  - flipped learning (1)
  - Gamificación (2)
  - Gastronomía/Vocabulario culinario (2)
  - imágenes (4)
  - inmigracion (5)
  - INMIGRANTES /REFUGIADOS (47)
  - interculturalidad (9)
  - JUEGOS (9)
  - la clase invertida (1)
  - La familia (1)
  - LA SALUD (1)
  - LA VIVIENDA (1)
  - LAS ENFERMEDADES (1)
  - LÉXICO (2)
  - LECTO-ESCRITURA (2)
  - LENGUAS DE ÁFRICA (1)
  - LENGUAS DE ÁFRICA (bambara (1)
  - Los pasados (1)
  - Los Reyes Magos (1)
  - MANUALES / UNIDADES DIDÁCTICAS (16)
  - ME gusta (1)
  - Navidad (1)
  - NO ME GUSTA (1)
  - Palabra favorita (1)
  - POEMAS (1)
  - POESÍA (1)
  - Pretérito imperfecto (1)
  - Pretérito indefinido (1)
  - Pretérito perfecto (1)
  - PROFESIONES/OFICIOS (1)
  - SALUDOS y PRESENTACIONES (1)
  - San Valentín (1)
  - SER y ESTAR (2)
  - swahili (1)
  - TALLERES (2)
  - Talleres de formación ELE inmigrantes (2)
  - TICS (1)
  - TIEMPOS VERBALES (9)
  - TRADICIONES (2)
  - VERBOS (10)
  - Vocabulario/léxico (16)
  - wolof (1)

- ###

  Más fotos

- ### Blog Stats

  - 4,169,016 hits

- ### VISITORS

- ### NOS ….(OTROS)

  Nunca a lo largo de la historia, la diversidad ha estado tan arraigada en nuestra piel como en estos albores del siglo XXI. Sólo la diferencia nos garantiza el derecho a ser reconocidos como distintos y la vez como iguales (en derechos, deberes y oportunidades). Si queremos construir futuro, únicamente hay una opción. Dar el paso, enseñar, ayudar a dar el paso para que ese encuentro con el otro se base en el diálogo, en el respeto, en el mutuo conocimiento y reconocimiento. El profesor Jesús Ángel Sánchez ha intentado que sus alumnos aprendiesen a ver con otra mirada a los hombres y mujeres que nos encontramos día a día en el aula, en la calle y en la vida. Podemos vivir, sentir y pensar en distintas lenguas, podemos llorar, querer y soñar con distintos esquemas culturales, pero sólo con los otros, nos...(otros) tenemos la oportunidad de construir un mundo mejor. NOS..(OTROS)

- ### WANAFRICA

  WANAFRICA

- ### UN DÍA EN LA VIDA DE ÁFRICA

  A DAY IN THE LIFE OF ÁFRICA

  ÁFRICA NEGRA

- ### MADY FOFANA

  Un maliense en La Mancha

- ### NOTICIAS EN BAMBARA

  INFORMATIVO EN MANDINGA

- ### CUENTOS DE ÁFRICA

  1.- IRENE EN EL SAHARA

  2.- IRENE EN SENEGAL

- ### CUENTOS DE MALI EN BAMBARA

  Cuentos en bambara

- ### CUENTOS DE SENEGAL EN WOLOF

  CUENTOS DE SENEGAL EN WOLOF

- ### CUENTOS DE MAURITANIA EN WOLOF Y BAMBARA

  Cuentos de Mauritania en wolof y bambara

- ### CUENTOS DEL MAGREB

  Cuentos del Magreb

- ### CUENTOS DEL MAGREB

- ### GENTE QUE MUEVE SU CASA

- enero 2016
  M | T | W | T | F | S | S
  --- | --- | --- | --- | --- | --- | ---
  « Dec |  |
  | 1 | 2 | 3
  4 | 5 | 6 | 7 | 8 | 9 | 10
  11 | 12 | 13 | 14 | 15 | 16 | 17
  18 | 19 | 20 | 21 | 22 | 23 | 24
  25 | 26 | 27 | 28 | 29 | 30 | 31

- ###

- ###

  - Nines Picado

- ###

- ### Etiquetas

  acróstico actividades BUSCO TRABAJO Dinámicas Gamificación diploma direcciones ELE español inmigrantes examen expresiones idiomáticas imágenes ELE Juegos léxico ME GUSTA NO ME GUSTA palabra favorita poema diamante poemas POESÍA Preguntar y dar direcciones preposiciones Saludos y presentaciones

Enviar a dirección de correo electrónico Su Nombre Tu dirección de correo electrónico
Cancelar
La entrada no fue enviada. ¡Comprueba tus direcciones de correo electrónico!
Error en la comprobación de email. Por favor, vuelve a intentarlo
Lo sentimos, tu blog no puede compartir entradas por correo electrónico.
A %d blogueros les gusta esto:

Publicar en
Cancelar